@@ -1,12 +1,13 @@
 package App::shcompgen;
 
-our $DATE = '2018-02-08'; # DATE
-our $VERSION = '0.321'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-04-03'; # DATE
+our $DIST = 'App-shcompgen'; # DIST
+our $VERSION = '0.322'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use experimental 'smartmatch';
 use Log::ger;
 
 use File::Slurper qw(read_text write_text);
@@ -182,7 +183,7 @@ sub _set_args_defaults {
         $n = "bash" if $n eq 'bourne'; # under make
         $args->{shell} = $n;
     }
-    unless ($args->{shell} ~~ @supported_shells) {
+    unless (grep { $_ eq $args->{shell} } @supported_shells) {
         return [412, "Unsupported shell '$args->{shell}'"];
     }
 
@@ -547,7 +548,7 @@ sub _detect_prog {
 
     my $is_perl_script = <$fh> =~ /perl/;
     seek $fh, 0, 0;
-    my $content = do { local $/; ~~<$fh> };
+    my $content = do { local $/; scalar <$fh> };
 
     my %extrametas;
 
@@ -883,7 +884,9 @@ sub init {
     }
 
     if ($shell eq 'bash') {
-        $init_location = $global ? "/etc/bash.bashrc" : "~/.bashrc";
+        $init_location = $global ?
+            (-d "/etc/profile.d" ? "/etc/profile.d/shcompgen.sh" : "/etc/bash.bashrc") :
+            "~/.bashrc";
         $init_script = <<_;
 # generated by shcompgen version $App::shcompgen::VERSION
 _
@@ -1153,7 +1156,7 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.321 of App::shcompgen (from Perl distribution App-shcompgen), released on 2018-02-08.
+This document describes version 0.322 of App::shcompgen (from Perl distribution App-shcompgen), released on 2020-04-03.
 
 =head1 FUNCTIONS
 
@@ -1162,7 +1165,7 @@ This document describes version 0.321 of App::shcompgen (from Perl distribution
 
 Usage:
 
- detect_prog(%args) -> [status, msg, result, meta]
+ detect_prog(%args) -> [status, msg, payload, meta]
 
 Detect a program.
 
@@ -1178,6 +1181,7 @@ Arguments ('*' denotes required arguments):
 
 Override guessing and select shell manually.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -1185,18 +1189,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 generate
 
 Usage:
 
- generate(%args) -> [status, msg, result, meta]
+ generate(%args) -> [status, msg, payload, meta]
 
 Generate shell completion scripts for detectable programs.
 
@@ -1298,6 +1303,7 @@ Directory to put completions scripts.
 
 Directory to put completions scripts.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -1305,18 +1311,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 guess_shell
 
 Usage:
 
- guess_shell() -> [status, msg, result, meta]
+ guess_shell() -> [status, msg, payload, meta]
 
 Guess running shell.
 
@@ -1329,18 +1336,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 init
 
 Usage:
 
- init(%args) -> [status, msg, result, meta]
+ init(%args) -> [status, msg, payload, meta]
 
 Initialize shcompgen.
 
@@ -1420,6 +1428,7 @@ Directory to put completions scripts.
 
 Directory to put completions scripts.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -1427,18 +1436,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 list
 
 Usage:
 
- list(%args) -> [status, msg, result, meta]
+ list(%args) -> [status, msg, payload, meta]
 
 List all shell completion scripts generated by this script.
 
@@ -1517,6 +1527,7 @@ Directory to put completions scripts.
 
 Directory to put completions scripts.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -1524,18 +1535,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 remove
 
 Usage:
 
- remove(%args) -> [status, msg, result, meta]
+ remove(%args) -> [status, msg, payload, meta]
 
 Remove shell completion scripts generated by this script.
 
@@ -1619,6 +1631,7 @@ Directory to put completions scripts.
 
 Directory to put completions scripts.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -1626,7 +1639,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -1654,7 +1667,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
